Crate imgui_ash

Crate imgui_ash 

Translation of the vulkan backend of Dear ImGui to imgui-rs.

Notable changes include the use of VMA through vk_mem

To get started fill out a RendererCreateInfo and render in each frame

use imgui_ash::{RendererCreateInfo, SurfaceColorFormat};


let create_info = RendererCreateInfo::default()
    .queue_family(your_queue_familiy)
    .queue(your_queue)
    .render_pass(your_render_pass)
    .subpass(your_subpass);
    .image_count(frames_in_flight)
    .msaa_samples(your_msaa_samples)
    .pipeline_cache(your_pipeline_cache)
    .surface_color_fmt(Some(SurfaceColorFormat::Srgb))
    .descriptor_pool_size(your_n_textures);

You can then pass this create info along with device to Renderer::new.

Thereafter one can just call Renderer::new_frame and Renderer::render upon each frame.

Structs

Renderer
RendererCreateInfo

Enums

FontsCreateError
RendererCreateError
RendererError
SurfaceColorFormat
Whether the outputting surface has a linear output format or a logarithmic srgb output format, generally linear is desired and is as such the default
TextureError

Constants

MIN_DESCRIPTOR_POOL_SIZE