pub enum SurfaceColorFormat {
Linear,
Srgb,
}Expand description
Whether the outputting surface has a linear output format or a logarithmic srgb output format, generally linear is desired and is as such the default
Variants